==> proc-that-0.4.0.tgz: package/Etl.js <==
"use strict";
var rxjs_1 = require('rxjs');
(function (EtlState) {
    EtlState[EtlState["Running"] = 0] = "Running";
    EtlState[EtlState["Stopped"] = 1] = "Stopped";
    EtlState[EtlState["Error"] = 2] = "Error";
})(exports.EtlState || (exports.EtlState = {}));
var EtlState = exports.EtlState;
/**
 * ETL Class. Instantiate one and add as many extractors, transformers and loaders as you want.
 * Then start the whole process with ".start()".
 *
 * This processor is modular, you can find other implemented loaders and extractors in the README
 */
var Etl = (function () {
    function Etl() {
        this._extractors = [];
        this._transformers = [];
        this._loaders = [];
        this._state = EtlState.Stopped;
    }
    Object.defineProperty(Etl.prototype, "extractors", {
        get: function () {
            return this._extractors;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "transformers", {
        get: function () {
            return this._transformers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "loaders", {
        get: function () {
            return this._loaders;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "state", {
        get: function () {
            return this._state;
        },
        enumerable: true,
        configurable: true
    });
    Etl.prototype.addExtractor = function (extract) {
        this._extractors.push(extract);
        return this;
    };
    Etl.prototype.addTransformer = function (transformer) {
        this._transformers.push(transformer);
        return this;
    };
    Etl.prototype.addLoader = function (loader) {
        this._loaders.push(loader);
        return this;
    };
    /**
     * Starts the etl process. First, all extractors are ran in parallel and deliver their results into an observable.
     * Once the buffer gets a result, it transfers all objects through the transformers (one by one).
     * After that, the transformed results are ran through all loaders in parallel.
     *
     * @returns {Observable<any>} Observable that completes when the process is finished,
     *                            during the "next" process step you get update on how many are processed yet.
     *                            Throws when any step produces an error.
     */
    Etl.prototype.start = function () {
        var _this = this;
        this._state = EtlState.Running;
        return rxjs_1.Observable.merge.apply(rxjs_1.Observable, this._extractors.map(function (extractor) { return extractor.read(); }))
            .flatMap(function (object) { return _this._transformers.reduce(function (observable, transformer) { return observable.flatMap(function (o) { return transformer.process(o); }); }, rxjs_1.Observable.of(object)); })
            .flatMap(function (object) { return rxjs_1.Observable.merge.apply(rxjs_1.Observable, _this._loaders.map(function (loader) { return loader.write(object); })); })
            .do(null, function (err) {
            _this._state = EtlState.Error;
            return rxjs_1.Observable.throw(err);
        }, function () {
            _this._state = EtlState.Stopped;
        });
    };
    /**
     * Resets the whole Etl object. Deletes all modifiers and resets the state.
     */
    Etl.prototype.reset = function () {
        this._extractors = [];
        this._transformers = [];
        this._loaders = [];
        this._state = EtlState.Stopped;
    };
    return Etl;
}());
exports.Etl = Etl;

==> proc-that-0.5.0.tgz: package/Etl.js <==
"use strict";
var MapTransformer_1 = require('./transformers/MapTransformer');
var rxjs_1 = require('rxjs');
(function (EtlState) {
    EtlState[EtlState["Running"] = 0] = "Running";
    EtlState[EtlState["Stopped"] = 1] = "Stopped";
    EtlState[EtlState["Error"] = 2] = "Error";
})(exports.EtlState || (exports.EtlState = {}));
var EtlState = exports.EtlState;
/**
 * ETL Class. Instantiate one and add as many extractors, transformers and loaders as you want.
 * Then start the whole process with ".start()".
 *
 * This processor is modular, you can find other implemented loaders and extractors in the README
 */
var Etl = (function () {
    function Etl() {
        this._extractors = [];
        this._generalTransformers = [];
        this._transformers = [];
        this._loaders = [];
        this._state = EtlState.Stopped;
    }
    Object.defineProperty(Etl.prototype, "extractors", {
        get: function () {
            return this._extractors;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "generalTransformers", {
        get: function () {
            return this._generalTransformers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "transformers", {
        get: function () {
            return this._transformers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "loaders", {
        get: function () {
            return this._loaders;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Etl.prototype, "state", {
        get: function () {
            return this._state;
        },
        enumerable: true,
        configurable: true
    });
    Etl.prototype.addExtractor = function (extract) {
        this._extractors.push(extract);
        return this;
    };
    Etl.prototype.addGeneralTransformer = function (transformer) {
        this._generalTransformers.push(transformer);
        return this;
    };
    Etl.prototype.addTransformer = function (transformer) {
        this.addGeneralTransformer(new MapTransformer_1.MapTransformer(transformer));
        this._transformers.push(transformer);
        return this;
    };
    Etl.prototype.addLoader = function (loader) {
        this._loaders.push(loader);
        return this;
    };
    /**
     * Starts the etl process. First, all extractors are run in parallel and deliver their results into an observable.
     * Once the buffer gets a result, it transfers all objects through the transformers (one by one).
     * After that, the transformed results are run through all loaders in parallel.
     *
     * @returns {Observable<any>} Observable that completes when the process is finished,
     *                            during the "next" process step you get update on how many are processed yet.
     *                            Throws when any step produces an error.
     */
    Etl.prototype.start = function () {
        var _this = this;
        this._state = EtlState.Running;
        var observable = rxjs_1.Observable.merge.apply(rxjs_1.Observable, this._extractors.map(function (extractor) { return extractor.read(); }));
        return this._generalTransformers.reduce(function (observable, transformer) { return transformer.process(observable); }, observable)
            .flatMap(function (object) { return rxjs_1.Observable.merge.apply(rxjs_1.Observable, _this._loaders.map(function (loader) { return loader.write(object); })); })
            .do(null, function (err) {
            _this._state = EtlState.Error;
            return rxjs_1.Observable.throw(err);
        }, function () {
            _this._state = EtlState.Stopped;
        });
    };
    /**
     * Resets the whole Etl object. Deletes all modifiers and resets the state.
     */
    Etl.prototype.reset = function () {
        this._extractors = [];
        this._transformers = [];
        this._loaders = [];
        this._state = EtlState.Stopped;
    };
    return Etl;
}());
exports.Etl = Etl;
